==> aws-cdk-scala-route53resolver_3-0.1.2-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"route53resolver","t":"route53resolver","d":"","k":"static"},
{"l":"io/burkard/cdk/services/route53resolver.html","n":"io.burkard.cdk.services.route53resolver","t":"package io.burkard.cdk.services.route53resolver","d":"io/burkard/cdk/services/route53resolver","k":"package"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallDomainList$.html","n":"CfnFirewallDomainList","t":"object CfnFirewallDomainList","d":"io/burkard/cdk/services/route53resolver/CfnFirewallDomainList$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallDomainList$.html","n":"apply","t":"def apply(internalResourceId: String, name: Option[String], tags: Option[List[_ <: CfnTag]], domains: Option[List[String]], domainFileUrl: Option[String])(implicit stackCtx: Stack): CfnFirewallDomainList","d":"io/burkard/cdk/services/route53resolver/CfnFirewallDomainList$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallDomainListProps$.html","n":"CfnFirewallDomainListProps","t":"object CfnFirewallDomainListProps","d":"io/burkard/cdk/services/route53resolver/CfnFirewallDomainListProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallDomainListProps$.html","n":"apply","t":"def apply(name: Option[String], tags: Option[List[_ <: CfnTag]], domains: Option[List[String]], domainFileUrl: Option[String]): CfnFirewallDomainListProps","d":"io/burkard/cdk/services/route53resolver/CfnFirewallDomainListProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroup$.html","n":"CfnFirewallRuleGroup","t":"object CfnFirewallRuleGroup","d":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroup$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroup$.html","n":"apply","t":"def apply(internalResourceId: String, name: Option[String], tags: Option[List[_ <: CfnTag]], firewallRules: Option[List[_]])(implicit stackCtx: Stack): CfnFirewallRuleGroup","d":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroup$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupAssociation$.html","n":"CfnFirewallRuleGroupAssociation","t":"object CfnFirewallRuleGroupAssociation","d":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupAssociation$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupAssociation$.html","n":"apply","t":"def apply(internalResourceId: String, mutationProtection: Option[String], vpcId: Option[String], tags: Option[List[_ <: CfnTag]], firewallRuleGroupId: Option[String], name: Option[String], priority: Option[Number])(implicit stackCtx: Stack): CfnFirewallRuleGroupAssociation","d":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupAssociation$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupAssociationProps$.html","n":"CfnFirewallRuleGroupAssociationProps","t":"object CfnFirewallRuleGroupAssociationProps","d":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupAssociationProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupAssociationProps$.html","n":"apply","t":"def apply(mutationProtection: Option[String], vpcId: Option[String], tags: Option[List[_ <: CfnTag]], firewallRuleGroupId: Option[String], name: Option[String], priority: Option[Number]): CfnFirewallRuleGroupAssociationProps","d":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupAssociationProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupProps$.html","n":"CfnFirewallRuleGroupProps","t":"object CfnFirewallRuleGroupProps","d":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupProps$.html","n":"apply","t":"def apply(name: Option[String], tags: Option[List[_ <: CfnTag]], firewallRules: Option[List[_]]): CfnFirewallRuleGroupProps","d":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverDNSSECConfig$.html","n":"CfnResolverDNSSECConfig","t":"object CfnResolverDNSSECConfig","d":"io/burkard/cdk/services/route53resolver/CfnResolverDNSSECConfig$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverDNSSECConfig$.html","n":"apply","t":"def apply(internalResourceId: String, resourceId: Option[String])(implicit stackCtx: Stack): CfnResolverDNSSECConfig","d":"io/burkard/cdk/services/route53resolver/CfnResolverDNSSECConfig$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverDNSSECConfigProps$.html","n":"CfnResolverDNSSECConfigProps","t":"object CfnResolverDNSSECConfigProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverDNSSECConfigProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverDNSSECConfigProps$.html","n":"apply","t":"def apply(resourceId: Option[String]): CfnResolverDNSSECConfigProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverDNSSECConfigProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverEndpoint$.html","n":"CfnResolverEndpoint","t":"object CfnResolverEndpoint","d":"io/burkard/cdk/services/route53resolver/CfnResolverEndpoint$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverEndpoint$.html","n":"apply","t":"def apply(internalResourceId: String, name: Option[String], tags: Option[List[_ <: CfnTag]], securityGroupIds: Option[List[String]], direction: Option[String], ipAddresses: Option[List[_]])(implicit stackCtx: Stack): CfnResolverEndpoint","d":"io/burkard/cdk/services/route53resolver/CfnResolverEndpoint$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverEndpointProps$.html","n":"CfnResolverEndpointProps","t":"object CfnResolverEndpointProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverEndpointProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverEndpointProps$.html","n":"apply","t":"def apply(name: Option[String], tags: Option[List[_ <: CfnTag]], securityGroupIds: Option[List[String]], direction: Option[String], ipAddresses: Option[List[_]]): CfnResolverEndpointProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverEndpointProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfig$.html","n":"CfnResolverQueryLoggingConfig","t":"object CfnResolverQueryLoggingConfig","d":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfig$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfig$.html","n":"apply","t":"def apply(internalResourceId: String, name: Option[String], destinationArn: Option[String])(implicit stackCtx: Stack): CfnResolverQueryLoggingConfig","d":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfig$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigAssociation$.html","n":"CfnResolverQueryLoggingConfigAssociation","t":"object CfnResolverQueryLoggingConfigAssociation","d":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigAssociation$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigAssociation$.html","n":"apply","t":"def apply(internalResourceId: String, resourceId: Option[String], resolverQueryLogConfigId: Option[String])(implicit stackCtx: Stack): CfnResolverQueryLoggingConfigAssociation","d":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigAssociation$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigAssociationProps$.html","n":"CfnResolverQueryLoggingConfigAssociationProps","t":"object CfnResolverQueryLoggingConfigAssociationProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigAssociationProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigAssociationProps$.html","n":"apply","t":"def apply(resourceId: Option[String], resolverQueryLogConfigId: Option[String]): CfnResolverQueryLoggingConfigAssociationProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigAssociationProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigProps$.html","n":"CfnResolverQueryLoggingConfigProps","t":"object CfnResolverQueryLoggingConfigProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigProps$.html","n":"apply","t":"def apply(name: Option[String], destinationArn: Option[String]): CfnResolverQueryLoggingConfigProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverRule$.html","n":"CfnResolverRule","t":"object CfnResolverRule","d":"io/burkard/cdk/services/route53resolver/CfnResolverRule$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverRule$.html","n":"apply","t":"def apply(internalResourceId: String, name: Option[String], tags: Option[List[_ <: CfnTag]], domainName: Option[String], ruleType: Option[String], targetIps: Option[List[_]], resolverEndpointId: Option[String])(implicit stackCtx: Stack): CfnResolverRule","d":"io/burkard/cdk/services/route53resolver/CfnResolverRule$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverRuleAssociation$.html","n":"CfnResolverRuleAssociation","t":"object CfnResolverRuleAssociation","d":"io/burkard/cdk/services/route53resolver/CfnResolverRuleAssociation$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverRuleAssociation$.html","n":"apply","t":"def apply(internalResourceId: String, name: Option[String], resolverRuleId: Option[String], vpcId: Option[String])(implicit stackCtx: Stack): CfnResolverRuleAssociation","d":"io/burkard/cdk/services/route53resolver/CfnResolverRuleAssociation$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverRuleAssociationProps$.html","n":"CfnResolverRuleAssociationProps","t":"object CfnResolverRuleAssociationProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverRuleAssociationProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverRuleAssociationProps$.html","n":"apply","t":"def apply(name: Option[String], resolverRuleId: Option[String], vpcId: Option[String]): CfnResolverRuleAssociationProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverRuleAssociationProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverRuleProps$.html","n":"CfnResolverRuleProps","t":"object CfnResolverRuleProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverRuleProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverRuleProps$.html","n":"apply","t":"def apply(name: Option[String], tags: Option[List[_ <: CfnTag]], domainName: Option[String], ruleType: Option[String], targetIps: Option[List[_]], resolverEndpointId: Option[String]): CfnResolverRuleProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverRuleProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/FirewallRuleProperty$.html","n":"FirewallRuleProperty","t":"object FirewallRuleProperty","d":"io/burkard/cdk/services/route53resolver/FirewallRuleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/FirewallRuleProperty$.html","n":"apply","t":"def apply(blockOverrideDnsType: Option[String], blockResponse: Option[String], action: Option[String], blockOverrideTtl: Option[Number], priority: Option[Number], blockOverrideDomain: Option[String], firewallDomainListId: Option[String]): FirewallRuleProperty","d":"io/burkard/cdk/services/route53resolver/FirewallRuleProperty$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/IpAddressRequestProperty$.html","n":"IpAddressRequestProperty","t":"object IpAddressRequestProperty","d":"io/burkard/cdk/services/route53resolver/IpAddressRequestProperty$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/IpAddressRequestProperty$.html","n":"apply","t":"def apply(ip: Option[String], subnetId: Option[String]): IpAddressRequestProperty","d":"io/burkard/cdk/services/route53resolver/IpAddressRequestProperty$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/TargetAddressProperty$.html","n":"TargetAddressProperty","t":"object TargetAddressProperty","d":"io/burkard/cdk/services/route53resolver/TargetAddressProperty$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/TargetAddressProperty$.html","n":"apply","t":"def apply(ip: Option[String], port: Option[String]): TargetAddressProperty","d":"io/burkard/cdk/services/route53resolver/TargetAddressProperty$","k":"def"},
{"l":"docs/index.html","n":"route53resolver","t":"route53resolver","d":"","k":"static"}];

==> aws-cdk-scala-route53resolver_3-0.1.3-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"route53resolver","t":"route53resolver","d":"","k":"static"},
{"l":"io/burkard/cdk/services/route53resolver.html","n":"io.burkard.cdk.services.route53resolver","t":"package io.burkard.cdk.services.route53resolver","d":"io/burkard/cdk/services/route53resolver","k":"package"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallDomainList$.html","n":"CfnFirewallDomainList","t":"object CfnFirewallDomainList","d":"io/burkard/cdk/services/route53resolver/CfnFirewallDomainList$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallDomainList$.html","n":"apply","t":"def apply(internalResourceId: String, name: Option[String], tags: Option[List[_ <: CfnTag]], domains: Option[List[String]], domainFileUrl: Option[String])(implicit stackCtx: Stack): CfnFirewallDomainList","d":"io/burkard/cdk/services/route53resolver/CfnFirewallDomainList$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallDomainListProps$.html","n":"CfnFirewallDomainListProps","t":"object CfnFirewallDomainListProps","d":"io/burkard/cdk/services/route53resolver/CfnFirewallDomainListProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallDomainListProps$.html","n":"apply","t":"def apply(name: Option[String], tags: Option[List[_ <: CfnTag]], domains: Option[List[String]], domainFileUrl: Option[String]): CfnFirewallDomainListProps","d":"io/burkard/cdk/services/route53resolver/CfnFirewallDomainListProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroup$.html","n":"CfnFirewallRuleGroup","t":"object CfnFirewallRuleGroup","d":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroup$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroup$.html","n":"apply","t":"def apply(internalResourceId: String, name: Option[String], tags: Option[List[_ <: CfnTag]], firewallRules: Option[List[_]])(implicit stackCtx: Stack): CfnFirewallRuleGroup","d":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroup$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupAssociation$.html","n":"CfnFirewallRuleGroupAssociation","t":"object CfnFirewallRuleGroupAssociation","d":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupAssociation$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupAssociation$.html","n":"apply","t":"def apply(internalResourceId: String, mutationProtection: Option[String], vpcId: Option[String], tags: Option[List[_ <: CfnTag]], firewallRuleGroupId: Option[String], name: Option[String], priority: Option[Number])(implicit stackCtx: Stack): CfnFirewallRuleGroupAssociation","d":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupAssociation$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupAssociationProps$.html","n":"CfnFirewallRuleGroupAssociationProps","t":"object CfnFirewallRuleGroupAssociationProps","d":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupAssociationProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupAssociationProps$.html","n":"apply","t":"def apply(mutationProtection: Option[String], vpcId: Option[String], tags: Option[List[_ <: CfnTag]], firewallRuleGroupId: Option[String], name: Option[String], priority: Option[Number]): CfnFirewallRuleGroupAssociationProps","d":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupAssociationProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupProps$.html","n":"CfnFirewallRuleGroupProps","t":"object CfnFirewallRuleGroupProps","d":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupProps$.html","n":"apply","t":"def apply(name: Option[String], tags: Option[List[_ <: CfnTag]], firewallRules: Option[List[_]]): CfnFirewallRuleGroupProps","d":"io/burkard/cdk/services/route53resolver/CfnFirewallRuleGroupProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverConfig$.html","n":"CfnResolverConfig","t":"object CfnResolverConfig","d":"io/burkard/cdk/services/route53resolver/CfnResolverConfig$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverConfig$.html","n":"apply","t":"def apply(internalResourceId: String, resourceId: Option[String], autodefinedReverseFlag: Option[String])(implicit stackCtx: Stack): CfnResolverConfig","d":"io/burkard/cdk/services/route53resolver/CfnResolverConfig$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverConfigProps$.html","n":"CfnResolverConfigProps","t":"object CfnResolverConfigProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverConfigProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverConfigProps$.html","n":"apply","t":"def apply(resourceId: Option[String], autodefinedReverseFlag: Option[String]): CfnResolverConfigProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverConfigProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverDNSSECConfig$.html","n":"CfnResolverDNSSECConfig","t":"object CfnResolverDNSSECConfig","d":"io/burkard/cdk/services/route53resolver/CfnResolverDNSSECConfig$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverDNSSECConfig$.html","n":"apply","t":"def apply(internalResourceId: String, resourceId: Option[String])(implicit stackCtx: Stack): CfnResolverDNSSECConfig","d":"io/burkard/cdk/services/route53resolver/CfnResolverDNSSECConfig$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverDNSSECConfigProps$.html","n":"CfnResolverDNSSECConfigProps","t":"object CfnResolverDNSSECConfigProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverDNSSECConfigProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverDNSSECConfigProps$.html","n":"apply","t":"def apply(resourceId: Option[String]): CfnResolverDNSSECConfigProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverDNSSECConfigProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverEndpoint$.html","n":"CfnResolverEndpoint","t":"object CfnResolverEndpoint","d":"io/burkard/cdk/services/route53resolver/CfnResolverEndpoint$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverEndpoint$.html","n":"apply","t":"def apply(internalResourceId: String, name: Option[String], tags: Option[List[_ <: CfnTag]], securityGroupIds: Option[List[String]], direction: Option[String], ipAddresses: Option[List[_]])(implicit stackCtx: Stack): CfnResolverEndpoint","d":"io/burkard/cdk/services/route53resolver/CfnResolverEndpoint$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverEndpointProps$.html","n":"CfnResolverEndpointProps","t":"object CfnResolverEndpointProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverEndpointProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverEndpointProps$.html","n":"apply","t":"def apply(name: Option[String], tags: Option[List[_ <: CfnTag]], securityGroupIds: Option[List[String]], direction: Option[String], ipAddresses: Option[List[_]]): CfnResolverEndpointProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverEndpointProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfig$.html","n":"CfnResolverQueryLoggingConfig","t":"object CfnResolverQueryLoggingConfig","d":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfig$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfig$.html","n":"apply","t":"def apply(internalResourceId: String, name: Option[String], destinationArn: Option[String])(implicit stackCtx: Stack): CfnResolverQueryLoggingConfig","d":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfig$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigAssociation$.html","n":"CfnResolverQueryLoggingConfigAssociation","t":"object CfnResolverQueryLoggingConfigAssociation","d":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigAssociation$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigAssociation$.html","n":"apply","t":"def apply(internalResourceId: String, resourceId: Option[String], resolverQueryLogConfigId: Option[String])(implicit stackCtx: Stack): CfnResolverQueryLoggingConfigAssociation","d":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigAssociation$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigAssociationProps$.html","n":"CfnResolverQueryLoggingConfigAssociationProps","t":"object CfnResolverQueryLoggingConfigAssociationProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigAssociationProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigAssociationProps$.html","n":"apply","t":"def apply(resourceId: Option[String], resolverQueryLogConfigId: Option[String]): CfnResolverQueryLoggingConfigAssociationProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigAssociationProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigProps$.html","n":"CfnResolverQueryLoggingConfigProps","t":"object CfnResolverQueryLoggingConfigProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigProps$.html","n":"apply","t":"def apply(name: Option[String], destinationArn: Option[String]): CfnResolverQueryLoggingConfigProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverQueryLoggingConfigProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverRule$.html","n":"CfnResolverRule","t":"object CfnResolverRule","d":"io/burkard/cdk/services/route53resolver/CfnResolverRule$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverRule$.html","n":"apply","t":"def apply(internalResourceId: String, name: Option[String], tags: Option[List[_ <: CfnTag]], domainName: Option[String], ruleType: Option[String], targetIps: Option[List[_]], resolverEndpointId: Option[String])(implicit stackCtx: Stack): CfnResolverRule","d":"io/burkard/cdk/services/route53resolver/CfnResolverRule$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverRuleAssociation$.html","n":"CfnResolverRuleAssociation","t":"object CfnResolverRuleAssociation","d":"io/burkard/cdk/services/route53resolver/CfnResolverRuleAssociation$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverRuleAssociation$.html","n":"apply","t":"def apply(internalResourceId: String, name: Option[String], resolverRuleId: Option[String], vpcId: Option[String])(implicit stackCtx: Stack): CfnResolverRuleAssociation","d":"io/burkard/cdk/services/route53resolver/CfnResolverRuleAssociation$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverRuleAssociationProps$.html","n":"CfnResolverRuleAssociationProps","t":"object CfnResolverRuleAssociationProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverRuleAssociationProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverRuleAssociationProps$.html","n":"apply","t":"def apply(name: Option[String], resolverRuleId: Option[String], vpcId: Option[String]): CfnResolverRuleAssociationProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverRuleAssociationProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverRuleProps$.html","n":"CfnResolverRuleProps","t":"object CfnResolverRuleProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverRuleProps$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/CfnResolverRuleProps$.html","n":"apply","t":"def apply(name: Option[String], tags: Option[List[_ <: CfnTag]], domainName: Option[String], ruleType: Option[String], targetIps: Option[List[_]], resolverEndpointId: Option[String]): CfnResolverRuleProps","d":"io/burkard/cdk/services/route53resolver/CfnResolverRuleProps$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/FirewallRuleProperty$.html","n":"FirewallRuleProperty","t":"object FirewallRuleProperty","d":"io/burkard/cdk/services/route53resolver/FirewallRuleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/FirewallRuleProperty$.html","n":"apply","t":"def apply(blockOverrideDnsType: Option[String], blockResponse: Option[String], action: Option[String], blockOverrideTtl: Option[Number], priority: Option[Number], blockOverrideDomain: Option[String], firewallDomainListId: Option[String]): FirewallRuleProperty","d":"io/burkard/cdk/services/route53resolver/FirewallRuleProperty$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/IpAddressRequestProperty$.html","n":"IpAddressRequestProperty","t":"object IpAddressRequestProperty","d":"io/burkard/cdk/services/route53resolver/IpAddressRequestProperty$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/IpAddressRequestProperty$.html","n":"apply","t":"def apply(ip: Option[String], subnetId: Option[String]): IpAddressRequestProperty","d":"io/burkard/cdk/services/route53resolver/IpAddressRequestProperty$","k":"def"},
{"l":"io/burkard/cdk/services/route53resolver/TargetAddressProperty$.html","n":"TargetAddressProperty","t":"object TargetAddressProperty","d":"io/burkard/cdk/services/route53resolver/TargetAddressProperty$","k":"object"},
{"l":"io/burkard/cdk/services/route53resolver/TargetAddressProperty$.html","n":"apply","t":"def apply(ip: Option[String], port: Option[String]): TargetAddressProperty","d":"io/burkard/cdk/services/route53resolver/TargetAddressProperty$","k":"def"},
{"l":"docs/index.html","n":"route53resolver","t":"route53resolver","d":"","k":"static"}];
